function [Jx,Jd] = jTimerC(t,x,d,z,p)
%x-continunous state vector
% x = [xTC yTC];
%z-discrete state vector
% z = [tresC onC];
%p-parameter vector
% p = [tauC];
%residual equation system
% r(1) = d(1) - z(2);
% r(2) = x(2) - x(1) + z(1);

Jx = zeros(2);
Jd = zeros(2);
Jx(2,:) = [-1 1];
Jd(1,:) = [1 0];
